@@ -1,6 +1,6 @@
 
 package Kevin::Commands::Util;
-$Kevin::Commands::Util::VERSION = '0.4.1';
+$Kevin::Commands::Util::VERSION = '0.5.3';
 use Mojo::Base -strict;
 
 # Borrowed from https://github.com/docker/go-units/blob/master/duration.go
@@ -8,16 +8,16 @@ use Mojo::Base -strict;
 sub _human_duration {
   my $seconds = shift;
 
-  return 'Less than a second' if $seconds < 1;
+  return 'less than a second' if $seconds < 1;
   return '1 second' if $seconds == 1;
   return sprintf '%d seconds', $seconds if $seconds < 60;
 
   my $minutes = int($seconds / 60);
-  return 'About a minute' if $minutes == 1;
+  return 'about a minute' if $minutes == 1;
   return sprintf '%d minutes', $minutes if $minutes < 46;
 
   my $hours = int($seconds / (60 * 60) + 0.5);
-  return 'About an hour' if $hours == 1;
+  return 'about an hour' if $hours == 1;
   return sprintf '%d hours', $hours      if $hours < 48;
   return sprintf '%d days',  $hours / 24 if $hours < 24 * 7 * 2;
   return sprintf '%d weeks',  $hours / (24 * 7) if $hours < 24 * 30 * 2;
@@ -27,7 +27,7 @@ sub _human_duration {
 }
 
 sub _created_since {
-  _human_duration(shift) . ' ago';
+  ucfirst _human_duration(shift) . ' ago';
 }
 
 sub _running_since {
@@ -67,7 +67,7 @@ Kevin::Commands::Util
 
 =head1 VERSION
 
-version 0.4.1
+version 0.5.3
 
 =head1 AUTHOR
 
